=============
Seaborn plots
=============

All of the plotters below forward plotting to the corresponding
seaborn_ methods.

.. toctree::
   :maxdepth: 1

   GallerySeabornBoxPlots.rst
   GallerySeabornScatterPlots.rst
   GallerySeabornDensityPlots.rst
   GallerySeabornHeatmapPlots.rst

Common options
==============

All of the seaborn plots accept the following options:

.. glossary::

   kwargs
      string

      Keyword arguments that will be passed to the seaborn command.
      command.
